import { __extends, __assign } from './../external/tslib/tslib.es6.js';
import React from 'react';
import classnames from 'classnames';
import debounce from 'lodash/debounce';
import getOr from 'lodash/fp/getOr';
import { suffixMetadata, parseMetadata } from '@highlight-ui/utils-commons';
import styles from './Table.module.scss.js';
import stackColumnsToTheLeft from './dom-helpers.js';
import { renderTd, renderTh, renderTr } from './default-renderers.js';

var Table = function (_super) {
  __extends(Table, _super);

  function Table(props) {
    var _this = _super.call(this, props) || this;

    _this.componentDidMount = function () {
      window.addEventListener('resize', _this.debouncedStackFixedColumns);

      _this.stackFixedColumns();
    };

    _this.componentDidUpdate = function () {
      return _this.debouncedStackFixedColumns();
    };

    _this.componentWillUnmount = function () {
      window.removeEventListener('resize', _this.debouncedStackFixedColumns);
    };

    _this.stackFixedColumns = function () {
      var fixedColumnCount = _this.props.fixedColumnCount;
      var tableElement = _this.tableRef.current;
      if (!fixedColumnCount || tableElement == null) return;
      stackColumnsToTheLeft(tableElement, fixedColumnCount);
    };

    _this.tableRef = /*#__PURE__*/React.createRef();
    _this.debouncedStackFixedColumns = debounce(_this.stackFixedColumns, 200);
    return _this;
  }

  Table.prototype.render = function () {
    var _a = this.props,
        className = _a.className,
        _b = _a.columns,
        columns = _b === void 0 ? [] : _b,
        _c = _a.data,
        data = _c === void 0 ? [] : _c,
        _d = _a.fixedColumnCount,
        fixedColumnCount = _d === void 0 ? 0 : _d,
        fixedHeader = _a.fixedHeader,
        _e = _a.renderTd,
        renderTd$1 = _e === void 0 ? renderTd : _e,
        _f = _a.renderTh,
        renderTh$1 = _f === void 0 ? renderTh : _f,
        _g = _a.renderTr,
        renderTr$1 = _g === void 0 ? renderTr : _g,
        metadata = _a.metadata,
        _h = _a.theme,
        theme = _h === void 0 ? 'default' : _h;
    var innerMetadata = suffixMetadata(metadata);
    return /*#__PURE__*/React.createElement("table", __assign({
      className: classnames(className, fixedHeader ? styles.fixedHeader : null, styles.table, styles["fixedColumnCount" + fixedColumnCount], theme ? styles[theme + "Theme"] : styles.defaultTheme),
      ref: this.tableRef
    }, parseMetadata(metadata)), /*#__PURE__*/React.createElement("thead", __assign({}, parseMetadata(innerMetadata('head'))), /*#__PURE__*/React.createElement("tr", __assign({}, parseMetadata(innerMetadata('headRow'))), columns.map(function (column) {
      return __assign({
        renderTh: renderTh$1
      }, column);
    }).map(function (column, columnIndex) {
      return column.renderTh({
        column: column,
        columnIndex: columnIndex,
        metadata: metadata
      });
    }))), /*#__PURE__*/React.createElement("tbody", __assign({}, parseMetadata(innerMetadata('body'))), data.map(function (dataRow, rowIndex) {
      return renderTr$1({
        children: columns.map(function (column) {
          return __assign({
            renderTd: renderTd$1
          }, column);
        }).map(function (column, columnIndex) {
          return column.renderTd({
            column: column,
            columnIndex: columnIndex,
            content: getOr(undefined, column.key || '', dataRow),
            dataRow: dataRow,
            rowIndex: rowIndex,
            metadata: metadata
          });
        }),
        dataRow: dataRow,
        rowIndex: rowIndex,
        metadata: metadata
      });
    })));
  };

  return Table;
}(React.Component);

export { Table as default };
//# sourceMappingURL=Table.js.map
